@@ -25,6 +25,16 @@ class TestCategorizedKeyExtraction:
                     time_condition_keys=[],
                 ),
             ),
+            pytest.param(
+                "Muss [1]",
+                CategorizedKeyExtract(
+                    hint_keys=[],
+                    requirement_constraint_keys=["1"],
+                    format_constraint_keys=[],
+                    package_keys=[],
+                    time_condition_keys=[],
+                ),
+            ),
             pytest.param(
                 "([1] U [2]) O ([1] X [3])",
                 CategorizedKeyExtract(
@@ -128,12 +138,6 @@ class TestCategorizedKeyExtraction:
                         requirement_constraints={"1": ConditionFulfilledValue.UNKNOWN},
                         packages={},
                     ),
-                    ContentEvaluationResult(
-                        hints={},
-                        format_constraints={},
-                        requirement_constraints={"1": ConditionFulfilledValue.NEUTRAL},
-                        packages={},
-                    ),
                 ],
                 id="0 FC, 1 RC",
             ),
