@@ -1,4 +1,3 @@
-# type:ignore[misc]
 """ Tests for the parsing of the conditions tests (Mussfeldprüfung) """
 import asyncio
 import datetime
@@ -29,7 +28,7 @@ class TestConditionParser:
             pytest.param(
                 # simple or_composition
                 "[1]O[2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "or_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -40,7 +39,7 @@ class TestConditionParser:
             pytest.param(
                 # simple or_composition with lower case "o"
                 "[1]o[2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "or_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -51,7 +50,7 @@ class TestConditionParser:
             pytest.param(
                 # simple and_composition with lower case "u"
                 "[1]u[2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -62,7 +61,7 @@ class TestConditionParser:
             pytest.param(
                 # simple or_composition with whitespace
                 " [1] O[ 2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "or_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -73,7 +72,7 @@ class TestConditionParser:
             pytest.param(
                 # simple or_composition with whitespace and tab
                 " [1]\tO[ 2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "or_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -118,7 +117,7 @@ class TestConditionParser:
             pytest.param(
                 # xor_composition
                 "[1]X[2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "xor_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -129,7 +128,7 @@ class TestConditionParser:
             pytest.param(
                 # xor_composition with lower case "x"
                 "[1]x[2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "xor_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -140,7 +139,7 @@ class TestConditionParser:
             pytest.param(
                 # xor_composition
                 "[1]⊻[2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "xor_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -151,7 +150,7 @@ class TestConditionParser:
             pytest.param(
                 # time condition
                 "[UB1]u[2]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree("time_condition", [Token("TIME_CONDITION_KEY", "UB1")]),
@@ -177,7 +176,7 @@ class TestConditionParser:
             pytest.param(
                 #  no brackets
                 " [1][987]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "then_also_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -188,7 +187,7 @@ class TestConditionParser:
             pytest.param(
                 #  two format constraints with an operator
                 "[901]U[987]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "901")]),
@@ -199,10 +198,10 @@ class TestConditionParser:
             pytest.param(
                 # format constraint is attached as suffix _without_ an operator
                 "([1]U[2])[987]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "then_also_composition",
                     [
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "and_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -216,11 +215,11 @@ class TestConditionParser:
             pytest.param(
                 # format constraint is attached as prefix _without_ an operator
                 "[987]([1]U[2])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "then_also_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "987")]),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "and_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -233,11 +232,11 @@ class TestConditionParser:
             pytest.param(
                 # MSCONS AHB, Kapitel 7
                 "([902] U [906] [46])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "902")]),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "then_also_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "906")]),
@@ -250,14 +249,14 @@ class TestConditionParser:
             pytest.param(
                 # two format constraints
                 "([950]([2]U[4]))O([951]([1]U[3]))",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "or_composition",
                     [
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "then_also_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "950")]),
-                                Tree(
+                                Tree(  # type:ignore[misc]
                                     "and_composition",
                                     [
                                         Tree("condition", [Token("CONDITION_KEY", "2")]),
@@ -266,11 +265,11 @@ class TestConditionParser:
                                 ),
                             ],
                         ),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "then_also_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "951")]),
-                                Tree(
+                                Tree(  # type:ignore[misc]
                                     "and_composition",
                                     [
                                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -306,7 +305,7 @@ class TestConditionParser:
             pytest.param(
                 # simple or_composition
                 "([1]O[2])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "or_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -317,10 +316,10 @@ class TestConditionParser:
             pytest.param(
                 # and/or combination, and in brackets
                 "([1]U[2])O[53]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "or_composition",
                     [
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "and_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -334,10 +333,10 @@ class TestConditionParser:
             pytest.param(
                 # and/or combination, or in brackets
                 "([1]O[2])U[53]",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -351,11 +350,11 @@ class TestConditionParser:
             pytest.param(
                 # and/or combination, or in brackets, different order
                 "[53]U([1]O[2])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "53")]),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "1")]),
@@ -368,17 +367,17 @@ class TestConditionParser:
             pytest.param(
                 # complex expression with two brackets
                 "([1]O[2])U([53]U[4]O[12])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "1")]),
                                 Tree("condition", [Token("CONDITION_KEY", "2")]),
                             ],
                         ),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
                                 Tree(
@@ -397,20 +396,20 @@ class TestConditionParser:
             pytest.param(
                 # complex expression with two brackets
                 "([1]∨[2])∧([53]∧[4]∨[12])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "1")]),
                                 Tree("condition", [Token("CONDITION_KEY", "2")]),
                             ],
                         ),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
-                                Tree(
+                                Tree(  # type:ignore[misc]
                                     "and_composition",
                                     [
                                         Tree("condition", [Token("CONDITION_KEY", "53")]),
@@ -426,15 +425,15 @@ class TestConditionParser:
             pytest.param(
                 # nested brackets
                 "[100]U([2]U([53]O[4]))",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree("condition", [Token("CONDITION_KEY", "100")]),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "and_composition",
                             [
                                 Tree("condition", [Token("CONDITION_KEY", "2")]),
-                                Tree(
+                                Tree(  # type:ignore[misc]
                                     "or_composition",
                                     [
                                         Tree("condition", [Token("CONDITION_KEY", "53")]),
@@ -449,11 +448,11 @@ class TestConditionParser:
             pytest.param(
                 # nested brackets
                 "[10P]U([1]O[2])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree(Token("RULE", "package"), [Token("PACKAGE_KEY", "10P")]),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
                                 Tree(Token("RULE", "condition"), [Token("CONDITION_KEY", "1")]),
@@ -466,11 +465,11 @@ class TestConditionParser:
             pytest.param(
                 # nested brackets
                 "[10P1..5]U([1]O[2])",
-                Tree(
+                Tree(  # type:ignore[misc]
                     "and_composition",
                     [
                         Tree(Token("RULE", "package"), [Token("PACKAGE_KEY", "10P"), Token("REPEATABILITY", "1..5")]),
-                        Tree(
+                        Tree(  # type:ignore[misc]
                             "or_composition",
                             [
                                 Tree(Token("RULE", "condition"), [Token("CONDITION_KEY", "1")]),
